@@ -11,13 +11,15 @@ use Moose::Role;
 with 'Vote::Count::TopCount' ;
 with 'Vote::Count::TieBreaker' ;
 
-our $VERSION='0.021';
+use Storable 3.15 'dclone';
+
+our $VERSION='0.022';
 
 =head1 NAME
 
 Vote::Count::IRV
 
-=head1 VERSION 0.021
+=head1 VERSION 0.022
 
 =cut
 
@@ -29,49 +31,44 @@ use List::Util qw( min max );
 # use Vote::Count::RankCount;
 # use Try::Tiny;
 use TextTableTiny 'generate_markdown_table';
-#use Data::Printer;
+# use Data::Printer;
 #use Data::Dumper;
 
-
-  # is( $allintie->{'winner'}, 0, 'tiebreaker with no winner returned 0');
-  # is( $allintie->{'tie'}, 1, 'tiebreaker with no winner tie is true');
-  # is_deeply( $allintie->{'tied'}, [ 'FUDGESWIRL', 'VANILLA' ],
-  #   'tiebreaker (multi tie) with no winner tied contains remaining tied choices');
-
-
-sub _IRVTieBreaker ( $I, $tiebreaker, $active, @choices ) {
-  if ( $tiebreaker eq 'all') { return @choices }
-  my $ranked = undef;
-  if ( $tiebreaker eq 'borda') {
-    $ranked = $I->Borda( $active );
-  } elsif ( $tiebreaker eq 'borda_all') {
-    $ranked = $I->Borda( $I->BallotSet()->{'choices'} );
-  } elsif ( $tiebreaker eq 'approval') {
-    $ranked = $I->Approval();
-  } elsif ( $tiebreaker eq 'grandjunction') {
-    my $GJ = $I->TieBreakerGrandJunction( @choices );
-    if( $GJ->{'winner'}) { return ( $GJ->{'winner'}) }
-    elsif( $GJ->{'tie'}) { return   $GJ->{'tied'}->@* }
-    else { die "unexpected (or no) result from $tiebreaker!\n"}
-  } else { die "undefined tiebreak method $tiebreaker!\n"}
-  my @highchoice = () ;
-  my $highest = 0;
-  my $counted = $ranked->RawCount();
-  for my $c (@choices) {
-    if ( $counted->{$c} > $highest ) {
-      @highchoice = ( $c );
-      $highest = $counted->{$c};
-    } elsif ( $counted->{$c} == $highest ) {
-      push @highchoice, $c;
-    }
+sub _ResolveTie (
+  $self, $active, $tiebreaker, @choices) {
+  return @choices if @choices == 1;
+  my %high = map
+    { $_ => 1 }
+   $self->TieBreaker(
+    $tiebreaker,
+    $active,
+    @choices );
+  if ( defined $self->{'last_tiebreaker'} ){
+    $self->logt( $self->{'last_tiebreaker'}{'terse'});
+    $self->logv( $self->{'last_tiebreaker'}{'verbose'});
+    $self->{'last_tiebreaker'} = undef;
   }
-  return @highchoice;
+  if ( @choices == scalar( keys %high ) ) { return @choices}
+# tiebreaker returns winner, we want losers!
+# use map to remove winner(s) from @choices.
+  my @low = sort (map { if ( $high{$_}) { } else { $_ } } @choices) ;
+  return @low;
 }
 
-sub RunIRV ( $self, $active = undef, $tiebreaker = 'all' ) {
-  unless ( defined $active ) { $active = $self->Active() }
+sub RunIRV ( $self, $active = undef, $tiebreaker=undef ) {
+# external $active should not be changed.
+  if ( defined $active ) { $active = dclone $active }
+# Object's active is altered by IRV.
+  else { $active = $self->Active() }
+  unless ( defined $tiebreaker ) {
+    if ( defined $self->TieBreakMethod() ) {
+      $tiebreaker = $self->TieBreakMethod();
+    } else {
+      $tiebreaker = 'all';
+    }
+  }
   # deref self->Active from any other references IRV alters it.
-  else { $self->{'Active'} = { $active->%* } }
+  # else { $self->{'Active'} = { $active->%* } }
   my $roundctr   = 0;
   my $maxround   = scalar( keys %{$active} );
   $self->logt( "Instant Runoff Voting",
@@ -91,10 +88,8 @@ IRVLOOP:
     if ( defined $majority->{'winner'} ) {
       return $majority;
     } else {
-      my @bottom = sort $self->_IRVTieBreaker(
-        $tiebreaker,
-        $active,
-        $round->ArrayBottom()->@* );
+      my @bottom = $self->_ResolveTie (
+        $active, $tiebreaker, $round->ArrayBottom()->@*);
       if ( scalar(@bottom) == scalar( keys %{$active} ) ) {
         # if there is a tie at the end, the finalists should
         # be both top and bottom and the active set.
@@ -136,11 +131,13 @@ Instant Runoff Voting Looks for a Majority Winner. If one isn't present the choi
 
 Instant Runoff Voting is easy to count by hand and meets the Later Harm and Condorcet Loser Criteria. It, unfortunately, fails a large number of consistency criteria; the order of candidate dropping matters and small changes to the votes of non-winning choices that result in changes to the dropping order can change the outcome.
 
+Instant Runoff Voting is also known as Alternative Vote and as the Hare Method. 
+
 =head2 Tie Handling
 
 There is no standard accepted method for IRV tie resolution, Eliminate All is a common one and the default.
 
-Returns a tie when all of the remaining choices are in a tie. An optional value to RunIRV is to specify tiebreaker, see _IRVTieBreaker.
+Returns a tie when all of the remaining choices are in a tie. An optional value to RunIRV is to specify tiebreaker, see TieBreaker.
 
 =head2 RunIRV
 
@@ -160,19 +157,13 @@ Returns results in a hashref which will be the results of  Vote::Count::TopCount
 
 Supports the Vote::Count logt, logv, and logd methods for providing details of the method.
 
-=head2 Private Method _IRVTieBreaker
+=head2 TieBreaker
 
-Implements some basic methods for resolving ties. By default RunIRV sets a variable of $tiebreaker = 'all', which is to delete all tied choices. Alternate values that can be set are 'borda' (Borda Count the currently active choices), 'borda_all' (Borda Count all of the Choices on the Ballots), 'grand_junction' is similar to that method and Approval. The Borda Count methods use the defaults.
+Uses TieBreaker from the TieBreaker Role. The default is 'all', which is to not break ties. 'none' the default for the Matrix (Condorcet) Object should not be used for IRV.
 
-All was chosen as the module default because it is Later Harm safe. Modified Grand Junction is the most resolveable.
+All was chosen as the module default because it is Later Harm safe. Modified Grand Junction is the most resolveable and is the recommended option.
 
-In the event that the tie-breaker returns a tie eliminate all is used, unless that would eliminate all choices, in which case the election returns a tie.
-
-Tie Break Methods not provided can be implemented by extending Vote::Count::Method::IRV and over-ride the _IRVTieBreaker Method.
-
-  my @remove = $self->_IRVTieBreaker( $tiebreaker, $active, @choices );
-
-_IRVTieBreaker returns a list, all choices in that list will be eliminated if there is a tie in the tiebreaker.
+In the event that the tie-breaker returns a tie eliminate all that remain tied is used, unless that would eliminate all choices, in which case the election returns a tie.
 
 =cut
 
@@ -197,4 +188,3 @@ LICENSE
 This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
 
 =cut
-
