@@ -11,13 +11,13 @@ no warnings 'experimental';
 use List::Util qw( min max sum );
 use Data::Printer;
 
-our $VERSION='0.023';
+our $VERSION='0.022';
 
 =head1 NAME
 
 Vote::Count::TieBreaker
 
-=head1 VERSION 0.023
+=head1 VERSION 0.022
 
 =cut
 
@@ -81,8 +81,8 @@ The Tie Breaking will be logged to the verbose log, any number of tied choices m
 =cut
 
 sub TieBreakerGrandJunction ( $self, @choices ) {
-  my $ballots = $self->BallotSet()->{'ballots'};
-  my %current = ( map { $_ => 0 } @choices );
+  my $ballots  = $self->BallotSet()->{'ballots'};
+  my %current  = ( map { $_ => 0 } @choices );
   my $deepest = 0;
   for my $b ( keys $ballots->%* ) {
     my $depth = scalar $ballots->{$b}{'votes'}->@*;
@@ -90,31 +90,31 @@ sub TieBreakerGrandJunction ( $self, @choices ) {
   }
   my $round = 1;
   while ( $round <= $deepest ) {
-    $self->logv("Tie Breaker Round: $round") if $self->can('logv');
+    $self->logv( "Tie Breaker Round: $round") if $self->can('logv');
     for my $b ( keys $ballots->%* ) {
-      my $pick = $ballots->{$b}{'votes'}[ $round - 1 ] or next;
+      my $pick = $ballots->{$b}{'votes'}[$round -1] or next ;
       if ( defined $current{$pick} ) {
         $current{$pick} += $ballots->{$b}{'count'};
       }
     }
     my $max = max( values %current );
-    for my $c ( sort @choices ) {
-      $self->logv("\t$c: $current{$c}") if $self->can('logv');
+    for my $c ( sort @choices ) { 
+      $self->logv( "\t$c: $current{$c}") if $self->can('logv');
     }
     for my $c ( sort @choices ) {
       if ( $current{$c} < $max ) {
         delete $current{$c};
-        $self->logv("Tie Breaker $c eliminated") if $self->can('logv');
+        $self->logv( "Tie Breaker $c eliminated") if $self->can('logv');
       }
     }
     @choices = ( sort keys %current );
     if ( 1 == @choices ) {
-      $self->logv("Tie Breaker Won By: $choices[0]") if $self->can('logv');
-      return { 'winner' => $choices[0], 'tie' => 0, 'tied' => [] };
+      $self->logv( "Tie Breaker Won By: $choices[0]") if $self->can('logv');
+      return { 'winner' => $choices[0], 'tie' => 0, 'tied' =>[]  };
     }
     $round++;
   }
-  return { 'winner' => 0, 'tie' => 1, 'tied' => \@choices };
+return { 'winner' => 0, 'tie' => 1, 'tied' => \@choices };
 }
 
 =head1 Borda-like Later Harm Protected
@@ -136,47 +136,39 @@ TieBreaker returns a list containing the winner, if the method is 'none' the lis
 =cut
 
 sub TieBreaker ( $I, $tiebreaker, $active, @choices ) {
-  if ( $tiebreaker eq 'all' )  { return @choices }
-  if ( $tiebreaker eq 'none' ) { return () }
-  my $choices_hashref = { map { $_ => 1 } @choices };
+  if ( $tiebreaker eq 'all') { return @choices }
+  if ( $tiebreaker eq 'none') { return () }
+  my $choices_hashref = {map { $_ => 1 } @choices};
   my $ranked = undef;
-  if ( $tiebreaker eq 'borda' ) {
-    $ranked = $I->Borda($active);
-  }
-  elsif ( $tiebreaker eq 'borda_all' ) {
+  if ( $tiebreaker eq 'borda') {
+    $ranked = $I->Borda( $active );
+  } elsif ( $tiebreaker eq 'borda_all') {
     $ranked = $I->Borda( $I->BallotSet()->{'choices'} );
-  }
-  elsif ( $tiebreaker eq 'approval' ) {
-    $ranked = $I->Approval($choices_hashref);
-    # } elsif ( $tiebreaker eq 'topcount') {
-    #   $ranked = $I->TopCount( $choices_hashref );
-  }
-  elsif ( $tiebreaker eq 'grandjunction' ) {
-    my $GJ = $I->TieBreakerGrandJunction(@choices);
-    if    ( $GJ->{'winner'} ) { return ( $GJ->{'winner'} ) }
-    elsif ( $GJ->{'tie'} )    { return $GJ->{'tied'}->@* }
-    else { die "unexpected (or no) result from $tiebreaker!\n" }
-  }
-  else { die "undefined tiebreak method $tiebreaker!\n" }
-  my @highchoice = ();
-  my $highest    = 0;
-  my $counted    = $ranked->RawCount();
+  } elsif ( $tiebreaker eq 'approval') {
+    $ranked = $I->Approval( $choices_hashref );
+  # } elsif ( $tiebreaker eq 'topcount') {
+  #   $ranked = $I->TopCount( $choices_hashref );
+  } elsif ( $tiebreaker eq 'grandjunction') {
+    my $GJ = $I->TieBreakerGrandJunction( @choices );
+    if( $GJ->{'winner'}) { return ( $GJ->{'winner'}) }
+    elsif( $GJ->{'tie'}) { return   $GJ->{'tied'}->@* }
+    else { die "unexpected (or no) result from $tiebreaker!\n"}
+  } else { die "undefined tiebreak method $tiebreaker!\n"}
+  my @highchoice = () ;
+  my $highest = 0;
+  my $counted = $ranked->RawCount();
   for my $c (@choices) {
     if ( $counted->{$c} > $highest ) {
-      @highchoice = ($c);
-      $highest    = $counted->{$c};
-    }
-    elsif ( $counted->{$c} == $highest ) {
+      @highchoice = ( $c );
+      $highest = $counted->{$c};
+    } elsif ( $counted->{$c} == $highest ) {
       push @highchoice, $c;
     }
   }
-  my $terse =
-      "Tie Breaker $tiebreaker: "
-    . join( ', ', @choices )
-    . "\nwinner(s): "
-    . join( ', ', @highchoice );
+  my $terse = "Tie Breaker $tiebreaker: " . join( ', ', @choices ) .
+    "\nwinner(s): " . join( ', ', @highchoice );
   $I->{'last_tiebreaker'} = {
-    'terse'   => $terse,
+    'terse' => $terse,
     'verbose' => $ranked->RankTable(),
   };
   return @highchoice;
